# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: colav_proto/obstaclesUpdate.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!colav_proto/obstaclesUpdate.proto\x12\x05\x63olav\"\xb1\x08\n\x0fObstaclesUpdate\x12\x13\n\x0bmission_tag\x18\x01 \x01(\t\x12\x41\n\x11\x64ynamic_obstacles\x18\x02 \x03(\x0b\x32&.colav.ObstaclesUpdate.DynamicObstacle\x12?\n\x10static_obstacles\x18\x03 \x03(\x0b\x32%.colav.ObstaclesUpdate.StaticObstacle\x12\x11\n\ttimestamp\x18\x04 \x01(\t\x1aL\n\nObstacleID\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x31\n\x04type\x18\x02 \x01(\x0e\x32#.colav.ObstaclesUpdate.ObstacleType\x1a\xe4\x01\n\x04Pose\x12\x36\n\x08position\x18\x01 \x01(\x0b\x32$.colav.ObstaclesUpdate.Pose.Position\x12<\n\x0borientation\x18\x02 \x01(\x0b\x32\'.colav.ObstaclesUpdate.Pose.Orientation\x1a+\n\x08Position\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x1a\x39\n\x0bOrientation\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x12\t\n\x01w\x18\x04 \x01(\x02\x1aV\n\x05State\x12)\n\x04pose\x18\x01 \x01(\x0b\x32\x1b.colav.ObstaclesUpdate.Pose\x12\x10\n\x08velocity\x18\x02 \x01(\x02\x12\x10\n\x08yaw_rate\x18\x03 \x01(\x02\x1a\\\n\x08Geometry\x12\x19\n\x11\x61\x63\x63\x65ptance_radius\x18\x01 \x01(\x02\x12\x35\n\x10polyshape_points\x18\x02 \x03(\x0b\x32\x1b.colav.ObstaclesUpdate.Pose\x1a\xa0\x01\n\x0f\x44ynamicObstacle\x12-\n\x02id\x18\x01 \x01(\x0b\x32!.colav.ObstaclesUpdate.ObstacleID\x12+\n\x05state\x18\x02 \x01(\x0b\x32\x1c.colav.ObstaclesUpdate.State\x12\x31\n\x08geometry\x18\x03 \x01(\x0b\x32\x1f.colav.ObstaclesUpdate.Geometry\x1a\x9d\x01\n\x0eStaticObstacle\x12-\n\x02id\x18\x01 \x01(\x0b\x32!.colav.ObstaclesUpdate.ObstacleID\x12)\n\x04pose\x18\x02 \x01(\x0b\x32\x1b.colav.ObstaclesUpdate.Pose\x12\x31\n\x08geometry\x18\x03 \x01(\x0b\x32\x1f.colav.ObstaclesUpdate.Geometry\"D\n\x0cObstacleType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\n\n\x06VESSEL\x10\x01\x12\r\n\tLAND_MASS\x10\x02\x12\x08\n\x04\x42UOY\x10\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'colav_proto.obstaclesUpdate_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OBSTACLESUPDATE']._serialized_start=45
  _globals['_OBSTACLESUPDATE']._serialized_end=1118
  _globals['_OBSTACLESUPDATE_OBSTACLEID']._serialized_start=236
  _globals['_OBSTACLESUPDATE_OBSTACLEID']._serialized_end=312
  _globals['_OBSTACLESUPDATE_POSE']._serialized_start=315
  _globals['_OBSTACLESUPDATE_POSE']._serialized_end=543
  _globals['_OBSTACLESUPDATE_POSE_POSITION']._serialized_start=441
  _globals['_OBSTACLESUPDATE_POSE_POSITION']._serialized_end=484
  _globals['_OBSTACLESUPDATE_POSE_ORIENTATION']._serialized_start=486
  _globals['_OBSTACLESUPDATE_POSE_ORIENTATION']._serialized_end=543
  _globals['_OBSTACLESUPDATE_STATE']._serialized_start=545
  _globals['_OBSTACLESUPDATE_STATE']._serialized_end=631
  _globals['_OBSTACLESUPDATE_GEOMETRY']._serialized_start=633
  _globals['_OBSTACLESUPDATE_GEOMETRY']._serialized_end=725
  _globals['_OBSTACLESUPDATE_DYNAMICOBSTACLE']._serialized_start=728
  _globals['_OBSTACLESUPDATE_DYNAMICOBSTACLE']._serialized_end=888
  _globals['_OBSTACLESUPDATE_STATICOBSTACLE']._serialized_start=891
  _globals['_OBSTACLESUPDATE_STATICOBSTACLE']._serialized_end=1048
  _globals['_OBSTACLESUPDATE_OBSTACLETYPE']._serialized_start=1050
  _globals['_OBSTACLESUPDATE_OBSTACLETYPE']._serialized_end=1118
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: colav_proto/controllerFeedback.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$colav_proto/controllerFeedback.proto\x12\x05\x63olav\"\xe4\x03\n\x12\x43ontrollerFeedback\x12\x13\n\x0bmission_tag\x18\x01 \x02(\t\x12\x11\n\tagent_tag\x18\x02 \x02(\t\x12>\n\tctrl_mode\x18\x03 \x02(\x0e\x32\".colav.ControllerFeedback.CTRLMode:\x07UNKNOWN\x12I\n\x0b\x63trl_status\x18\x04 \x02(\x0e\x32$.colav.ControllerFeedback.CTRLStatus:\x0eUNKNOWN_STATUS\x12\x35\n\x08\x63trl_cmd\x18\x05 \x02(\x0b\x32#.colav.ControllerFeedback.CmdVelYaw\x12\x11\n\ttimestamp\x18\x06 \x02(\t\x1a/\n\tCmdVelYaw\x12\x10\n\x08velocity\x18\x01 \x02(\x02\x12\x10\n\x08yaw_rate\x18\x02 \x02(\x02\"Y\n\x08\x43TRLMode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x43RUISE\x10\x01\x12\t\n\x05T2LOS\x10\x02\x12\x0b\n\x07T2Theta\x10\x03\x12\x06\n\x02\x46\x42\x10\x04\x12\x14\n\x10WAYPOINT_REACHED\x10\x05\"E\n\nCTRLStatus\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02\x12\t\n\x05\x45RROR\x10\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'colav_proto.controllerFeedback_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CONTROLLERFEEDBACK']._serialized_start=48
  _globals['_CONTROLLERFEEDBACK']._serialized_end=532
  _globals['_CONTROLLERFEEDBACK_CMDVELYAW']._serialized_start=323
  _globals['_CONTROLLERFEEDBACK_CMDVELYAW']._serialized_end=370
  _globals['_CONTROLLERFEEDBACK_CTRLMODE']._serialized_start=372
  _globals['_CONTROLLERFEEDBACK_CTRLMODE']._serialized_end=461
  _globals['_CONTROLLERFEEDBACK_CTRLSTATUS']._serialized_start=463
  _globals['_CONTROLLERFEEDBACK_CTRLSTATUS']._serialized_end=532
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: colav_proto/agentUpdate.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63olav_proto/agentUpdate.proto\x12\x05\x63olav\"\xba\x03\n\x0b\x41gentUpdate\x12\x13\n\x0bmission_tag\x18\x01 \x02(\t\x12\x11\n\tagent_tag\x18\x02 \x02(\t\x12\'\n\x05state\x18\x03 \x02(\x0b\x32\x18.colav.AgentUpdate.State\x12\x11\n\ttimestamp\x18\x04 \x02(\t\x1a\xdc\x01\n\x04Pose\x12\x32\n\x08position\x18\x01 \x02(\x0b\x32 .colav.AgentUpdate.Pose.Position\x12\x38\n\x0borientation\x18\x02 \x02(\x0b\x32#.colav.AgentUpdate.Pose.Orientation\x1a+\n\x08Position\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\x12\t\n\x01z\x18\x03 \x02(\x02\x1a\x39\n\x0bOrientation\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\x12\t\n\x01z\x18\x03 \x02(\x02\x12\t\n\x01w\x18\x04 \x02(\x02\x1ah\n\x05State\x12%\n\x04pose\x18\x01 \x02(\x0b\x32\x17.colav.AgentUpdate.Pose\x12\x10\n\x08velocity\x18\x02 \x02(\x02\x12\x10\n\x08yaw_rate\x18\x03 \x02(\x02\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x04 \x02(\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'colav_proto.agentUpdate_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_AGENTUPDATE']._serialized_start=41
  _globals['_AGENTUPDATE']._serialized_end=483
  _globals['_AGENTUPDATE_POSE']._serialized_start=157
  _globals['_AGENTUPDATE_POSE']._serialized_end=377
  _globals['_AGENTUPDATE_POSE_POSITION']._serialized_start=275
  _globals['_AGENTUPDATE_POSE_POSITION']._serialized_end=318
  _globals['_AGENTUPDATE_POSE_ORIENTATION']._serialized_start=320
  _globals['_AGENTUPDATE_POSE_ORIENTATION']._serialized_end=377
  _globals['_AGENTUPDATE_STATE']._serialized_start=379
  _globals['_AGENTUPDATE_STATE']._serialized_end=483
# @@protoc_insertion_point(module_scope)
